@@ -1,17 +1,18 @@
 #' Perform significance testing for single fixed factor analysis
 #' 
-#' @description  Significance testing for datasets with single reader in 
-#'    multiple (at least two) treatments, or single treatment with multiple 
+#' @description  Significance testing for datasets with a single reader in 
+#'    multiple (at least two) treatments, or a single treatment with multiple 
 #'    (at least two) readers, where reader or treatment, respectively, is 
 #'    regarded as a fixed factor and a common case-set, regarded as random, 
 #'    is assumed.
 #' 
 #' @param dataset A single-treatment or single-reader dataset.
-#' @param FOM The figure of merit, default  \code{"wAFROC"}, 
-#'    see \code{\link{UtilFigureOfMerit}}.
+#' @param FOM The figure of merit, see \code{\link{UtilFigureOfMerit}}.
 #' @param alpha The significance level (\code{alpha}, default 0.05) 
 #'    of the test of the null hypothesis that FOMs of all levels of 
 #'    the fixed factor are identical.
+#' @param FPFValue Only needed for \code{LROC} data \strong{and} FOM = "PCL" or "ALROC";
+#'     where to evaluate a partial curve based figure of merit. The default is 0.2.
 #' 
 #' @return The return value is a list containing:
 #' @return \item{f}{The observed F-statistic for testing the null 
@@ -50,26 +51,16 @@
 #' 
 #' @export
 
-StSignificanceTestingSingleFixedFactor <- function(dataset, FOM = "wAFROC", alpha = 0.05) {
-  NL <- dataset$NL
-  LL <- dataset$LL
-  lesionNum <- dataset$lesionNum
-  lesionID <- dataset$lesionID
-  lesionWeight <- dataset$lesionWeight
-  maxNL <- dim(NL)[4]
-  maxLL <- dim(LL)[4]
-  dataType <- dataset$dataType
+StSignificanceTestingSingleFixedFactor <- function(dataset, FOM, FPFValue = 0.2, alpha = 0.05) { # FPFValue only needed for LROC data
   modalityID <- dataset$modalityID
   readerID <- dataset$readerID
   I <- length(modalityID)
   J <- length(readerID)
-  K <- dim(NL)[3]
-  K2 <- dim(LL)[3]
-  K1 <- K - K2
-  
-  MS <- UtilMeanSquares(dataset, FOM)
-  pseudoValues <- UtilPseudoValues(dataset, FOM)
-  fomArray <- UtilFigureOfMerit(dataset, FOM)
+  K <- dim(dataset$NL)[3]
+
+  MS <- UtilMeanSquares(dataset, FOM, method = "DBMH", FPFValue)
+  pseudoValues <- UtilPseudoValues(dataset, FOM, FPFValue)$jkPseudoValues
+  fomArray <- UtilFigureOfMerit(dataset, FOM, FPFValue)
   if (I == 1 && J != 1){
     fDbmFixed <- MS$msR / MS$msRC
     ddf <- (J - 1) * (K - 1)
